@@ -1,7 +1,6 @@
 # This dummy function definition is included with the package to ensure that
 # 'tools::package_native_routine_registration_skeleton()' generates the required
 # registration info for the 'run_testthat_tests' symbol.
-# Commented out due to the LTO on CRAN.
-# (function() {
-#   .Call("run_testthat_tests", FALSE, PACKAGE = "fastcpd")
-# })
+(function() {
+  .Call("run_testthat_tests", FALSE, PACKAGE = "fastcpd")
+})
