@@ -95,7 +95,7 @@ context("get_nll_wo_cv Unit Test") {
   }
 }
 
-context("cost_update_gradient Unit Test") {
+context("get_gradient Unit Test") {
   test_that("arma(3, 2) is correct for 200 data points") {
     fastcpd::classes::Fastcpd fastcpd_class(
       /* beta */ 0,
@@ -127,14 +127,15 @@ context("cost_update_gradient Unit Test") {
     );
 
     const colvec theta = 0.1 * ones<colvec>(6);
-    const colvec gradient = fastcpd_class.cost_update_gradient(0, 199, theta);
+    const colvec gradient =
+      (fastcpd_class.*fastcpd_class.get_gradient)(0, 199, theta);
     const colvec expected_gradient =
       {4.401258, 6.600128, -7.591818, 4.151778, 7.503752, -2.806806};
     expect_true(norm(gradient - expected_gradient, "fro") < 1e-6);
   }
 }
 
-context("cost_update_hessian Unit Test") {
+context("get_hessian Unit Test") {
   test_that("binomal is correct for a two dimensional data") {
     fastcpd::classes::Fastcpd fastcpd_class(
       /* beta */ 0,
@@ -166,7 +167,7 @@ context("cost_update_hessian Unit Test") {
     );
 
     const colvec theta = {-0.5, 0.3};
-    const mat hessian = fastcpd_class.cost_update_hessian(0, 0, theta);
+    const mat hessian = (fastcpd_class.*fastcpd_class.get_hessian)(0, 0, theta);
     const mat expected_hessian =
         {{0.238'28, 0.047'656}, {0.047'656, 0.009'531'2}};
     expect_true(norm(hessian - expected_hessian, "fro") < 0.000'001);
@@ -203,7 +204,7 @@ context("cost_update_hessian Unit Test") {
     );
 
     const colvec theta = {-0.5, 0.3};
-    const mat hessian = fastcpd_class.cost_update_hessian(0, 0, theta);
+    const mat hessian = (fastcpd_class.*fastcpd_class.get_hessian)(0, 0, theta);
     const mat expected_hessian =
         {{0.644'036'4, 0.128'807}, {0.128'807, 0.025'761'6}};
     expect_true(norm(hessian - expected_hessian, "fro") < 0.000'001);
@@ -240,7 +241,8 @@ context("cost_update_hessian Unit Test") {
     );
 
     const colvec theta = 0.1 * ones<colvec>(6);
-    const mat hessian = fastcpd_class.cost_update_hessian(0, 199, theta);
+    const mat hessian =
+      (fastcpd_class.*fastcpd_class.get_hessian)(0, 199, theta);
     const mat expected_hessian = {
       { 12.406525,  18.60483, -21.40027,   4.743794,  28.98263, -44.01258},
       { 18.604831,  27.89981, -32.09185,  25.380851,  27.48253, -66.00128},
